#
# Procedures MBrickObject, MBrick and FourMBricks.
#
# $Id: mbrick_procs.tcl,v 1.3 1996/05/26 20:19:28 markd Exp $
#

proc MBrickObject {cubeShader ellipShader knobShader final} {
    set cubeSide 4.0
    set cube [SippCube $cubeSide $cubeShader]

    set res [expr $final ? 60 : 12]
    set ellip [SippEllipsoid {1.3 1.8 1.3} $res $ellipShader]
    SippObjectMove $ellip {0.0 1.7 0.0}
    SippObjectAddSubobj $cube $ellip
    SippObjectUnref $ellip

    set res [expr $final ? 30 : 5]
    set cubeHalf [expr $cubeSide / 2]
    set moveList [list [list $cubeHalf 0 0]  [list 0 0 $cubeHalf] \
                       [list -$cubeHalf 0 0] [list 0 0 -$cubeHalf]]

    foreach move $moveList {
        set knob [SippSphere 0.5 $res $knobShader]
        SippObjectMove $knob $move
        SippObjectAddSubobj $cube $knob
        SippObjectUnref $knob
    }

    return $cube
}

proc MBrick {final} {
    set cubeShader [SippShaderGranite 0.1 0.3 1.0 100.0 \
                                     {1.0 0.1 0.1} {0.1 0.1 0.1}]
    set ellipShader [SippShaderBasic 0.4 0.6 0.2 {0.0 0.0 1.0}]
    set knobShader [SippShaderBasic 0.4 0.6 0.2 {0.0 1.0 0.0}]

    set obj [MBrickObject $cubeShader $ellipShader $knobShader $final]

    SippShaderUnref $cubeShader
    SippShaderUnref $ellipShader
    SippShaderUnref $knobShader

    return $obj
}

proc FourMBricks {final} {
    set moveList [list [list  0  0 -6] \
                       [list  6  0  0] \
                       [list  0  0  6] \
                       [list -6  0  0]]

    # Create mbrick objects.

    foreach move $moveList {
        if ![info exists obj] {
            set obj [MBrick $final]
        } else {
            set obj [SippObjectInstance $obj]
        }
        SippObjectMove $obj $move
        lappend objList $obj 
    }

    # Create base for mbricks to sit on.

    set shader [SippShaderBasic 0.5 0.4 0.3 {0.5 0.6 0.8}]
    set obj [SippBlock {20.0 0.1 20.0} $shader]
    SippShaderUnref $shader
    SippObjectMove $obj {0 -2.05 0}
    lappend objList $obj

    # Create surfaceless object to containing all other objects.

    set topObj [SippObjectCreate]
    SippObjectAddSubobj $topObj $objList
    SippObjectUnref $objList
    return $topObj
}
